==> openjdk-src-19.0.1.u10-2-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_sq.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_sq extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "Lek\u00eb" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BRL", "BRL" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "CNH", "CNH" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LTL", "LTL" },
            { "LVL", "LVL" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "STN", "STN" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VES", "VES" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "aed", "Dirhami i Emirateve t\u00eb Bashkuara Arabe" },
            { "afn", "Afgani afgan" },
            { "all", "Leku shqiptar" },
            { "amd", "Dramia armene" },
            { "ang", "Gilderi antilian holandez" },
            { "aoa", "Kuanza e Angol\u00ebs" },
            { "ars", "Pesoja argjentinase" },
            { "aud", "Dollari australian" },
            { "awg", "Florini aruban" },
            { "azn", "Manata azerbajxhanase" },
            { "bam", "Marka e Bosnj\u00eb-Hercegovin\u00ebs [e shk\u00ebmbyeshme]" },
            { "bbd", "Dollari barbadian" },
            { "bdt", "Taka e Bangladeshit" },
            { "bgn", "Leva bullgare" },
            { "bhd", "Dinari i Bahreinit" },
            { "bif", "Franga burundiane" },
            { "bmd", "Dollari i Bermudeve" },
            { "bnd", "Dollari i Bruneit" },
            { "bob", "Boliviani i Bolivis\u00eb" },
            { "brl", "Reali brazilian" },
            { "bsd", "Dollari i Bahamasit" },
            { "btn", "Ngultrumi butanez" },
            { "bwp", "Pula botsuane" },
            { "byn", "Rubla bjelloruse" },
            { "byr", "Rubla bjelloruse (2000\u20132016)" },
            { "bzd", "Dollari i Ishujve Belize" },
            { "cad", "Dollari kanadez" },
            { "cdf", "Franga kongole" },
            { "chf", "Franga zvicerane" },
            { "clp", "Pesoja kiliane" },
            { "cnh", "Juani kinez (p\u00ebr treg t\u00eb jasht\u00ebm)" },
            { "cny", "Juani kinez" },
            { "cop", "Pesoja kolumbiane" },
            { "crc", "Koloni kostarikan" },
            { "cuc", "Pesoja kubaneze e shk\u00ebmbyeshme" },
            { "cup", "Pesoja kubaneze" },
            { "cve", "Eskudoja e Kepit t\u00eb Gjelb\u00ebr" },
            { "czk", "Koruna e \u00c7ekis\u00eb" },
            { "djf", "Franga xhibutiane" },
            { "dkk", "Korona daneze" },
            { "dop", "Pesoja dominikane" },
            { "dzd", "Dinari algjerian" },
            { "egp", "Sterlina egjiptiane" },
            { "ern", "Nakfa e Eritres\u00eb" },
            { "etb", "Bira etiopiane" },
            { "eur", "Euroja" },
            { "fjd", "Dollari i Fixhit" },
            { "fkp", "St\u00ebrlina e Ishujve Falkland" },
            { "gbp", "Sterlina britanike" },
            { "gel", "Laria gjeorgjiane" },
            { "ghs", "Sejda ganeze" },
            { "gip", "Sterlina e Gjibraltarit" },
            { "gmd", "Dalasi gambian" },
            { "gnf", "Franga guinease" },
            { "gtq", "Kuecali i Guatemal\u00ebs" },
            { "gyd", "Dollari guajanez" },
            { "hkd", "Dollari i Hong-Kongut" },
            { "hnl", "Lempira hondurase" },
            { "hrk", "Kuna kroate" },
            { "htg", "Gurdi haitian" },
            { "huf", "Forinta hungareze" },
            { "idr", "Rupia indoneziane" },
            { "ils", "Shekeli izrealit" },
            { "inr", "Rupia indiane" },
            { "iqd", "Dinari irakian" },
            { "irr", "Riali iranian" },
            { "isk", "Korona islandeze" },
            { "jmd", "Dollari xhamajkan" },
            { "jod", "Dinari jordanez" },
            { "jpy", "Jeni japonez" },
            { "kes", "Shilinga keniane" },
            { "kgs", "Soma kirgize" },
            { "khr", "Riali kamboxhian" },
            { "kmf", "Franga komore" },
            { "kpw", "Uoni koreano-verior" },
            { "krw", "Uoni koreano-jugor" },
            { "kwd", "Dinari kuvajtian" },
            { "kyd", "Dollari i Ishujve Kajman" },
            { "kzt", "Tenga kazake" },
            { "lak", "Kipa e Laosit" },
            { "lbp", "Sterlina libaneze" },
            { "lkr", "Rupia e Sri-Lank\u00ebs" },
            { "lrd", "Dollari liberian" },
            { "lsl", "Lota lesotiane" },
            { "ltl", "Lita lituaneze" },
            { "lvl", "Lata letoneze" },
            { "lyd", "Dinari libian" },
            { "mad", "Dirhami maroken" },
            { "mdl", "Leuja moldave" },
            { "mga", "Arieri malagez" },
            { "mkd", "Denari maqedonas" },
            { "mmk", "Kiata e Mianmarit" },
            { "mnt", "Tugrika mongole" },
            { "mop", "Pataka e Makaos" },
            { "mro", "Ugija mauritane (1973\u20132017)" },
            { "mru", "Ugija mauritane" },
            { "mur", "Rupia mauritiane" },
            { "mvr", "Rufiu i Maldivit" },
            { "mwk", "Kua\u00e7a malaviane" },
            { "mxn", "Pesoja meksikane" },
            { "myr", "Ringiti malajzian" },
            { "mzn", "Metikali i Mozambikut" },
            { "nad", "Dollari i Namibis\u00eb" },
            { "ngn", "Naira nigeriane" },
            { "nio", "Kordoba nikaraguane" },
            { "nok", "Korona norvegjeze" },
            { "npr", "Rupia nepaleze" },
            { "nzd", "Dollari i Zeland\u00ebs s\u00eb Re" },
            { "omr", "Riali i Omanit" },
            { "pab", "Balboa panameze" },
            { "pen", "Sola peruane" },
            { "pgk", "Kina e Guines\u00eb s\u00eb Re-Papua" },
            { "php", "Pesoja filipinase" },
            { "pkr", "Rupia pakistaneze" },
            { "pln", "Zllota polake" },
            { "pyg", "Guarani paraguaian" },
            { "qar", "Riali i Katarit" },
            { "ron", "Leuja rumune" },
            { "rsd", "Dinari serb" },
            { "rub", "Rubla ruse" },
            { "rwf", "Franga ruandeze" },
            { "sar", "Riali saudit" },
            { "sbd", "Dollari i Ishujve Solomon\u00eb" },
            { "scr", "Rupia e Ishujve Sishel\u00eb" },
            { "sdg", "Sterlina sudaneze" },
            { "sek", "Korona suedeze" },
            { "sgd", "Dollari i Singaporit" },
            { "shp", "Sterlina e Ishullit t\u00eb Sh\u00ebn-Helen\u00ebs" },
            { "sll", "Leoni i Sierra-Leones" },
            { "sos", "Shilinga somaleze" },
            { "srd", "Dollari surinamez" },
            { "ssp", "Sterlina sudanezo-jugore" },
            { "std", "Dobra e Sao-Tomes dhe Prinsipes (1977\u20132017)" },
            { "stn", "Dobra e Sao-Tomes dhe Prinsipes" },
            { "syp", "Sterlina siriane" },
            { "szl", "Lilangeni i Suaziland\u00ebs" },
            { "thb", "Bata tajlandeze" },
            { "tjs", "Somona taxhike" },
            { "tmt", "Manata turkmene" },
            { "tnd", "Dinari tunizian" },
            { "top", "Panga tongane" },
            { "try", "Lira turke" },
            { "ttd", "Dollari i Trinidadit dhe Tobagos" },
            { "twd", "Dollari tajvanez" },
            { "tzs", "Shilinga e Tanzanis\u00eb" },
            { "uah", "Rivnia ukrainase" },
            { "ugx", "Shilinga ugandeze" },
            { "usd", "Dollari amerikan" },
            { "uyu", "Pesoja uruguaiane" },
            { "uzs", "Soma uzbeke" },
            { "vef", "Bolivari venezuelian (2008\u20132018)" },
            { "ves", "Bolivari venezuelas" },
            { "vnd", "Donga vietnameze" },
            { "vuv", "Vatuja e Vanuatus\u00eb" },
            { "wst", "Tala samoane" },
            { "xaf", "Franga kamerunase" },
            { "xcd", "Dollari i Karaibeve Lindore" },
            { "xof", "Franga e Bregut t\u00eb Fildisht\u00eb" },
            { "xpf", "Franga franceze e Polinezis\u00eb" },
            { "xxx", "Valut\u00eb e panjohur" },
            { "yer", "Riali i Jemenit" },
            { "zar", "Randi afrikano-jugor" },
            { "zmw", "Kua\u00e7a e Zambikut" },
        };
        return data;
    }
}

==> openjdk-src-23.0.2.u7-1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_sq.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_sq extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "ALL", "Lek\u00eb" },
            { "BRL", "BRL" },
            { "PHP", "PHP" },
            { "THB", "\u0e3f" },
            { "aed", "Dirhami i Emirateve t\u00eb Bashkuara Arabe" },
            { "afn", "Afgani afgan" },
            { "all", "Leku shqiptar" },
            { "amd", "Dramia armene" },
            { "ang", "Gilderi antilian holandez" },
            { "aoa", "Kuanza e Angol\u00ebs" },
            { "ars", "Pesoja argjentinase" },
            { "aud", "Dollari australian" },
            { "awg", "Florini aruban" },
            { "azn", "Manata azerbajxhanase" },
            { "bam", "Marka e Bosnj\u00eb-Hercegovin\u00ebs [e shk\u00ebmbyeshme]" },
            { "bbd", "Dollari barbadian" },
            { "bdt", "Taka e Bangladeshit" },
            { "bgn", "Leva bullgare" },
            { "bhd", "Dinari i Bahreinit" },
            { "bif", "Franga burundiane" },
            { "bmd", "Dollari i Bermudeve" },
            { "bnd", "Dollari i Bruneit" },
            { "bob", "Boliviani i Bolivis\u00eb" },
            { "brl", "Reali brazilian" },
            { "bsd", "Dollari i Bahamasit" },
            { "btn", "Ngultrumi butanez" },
            { "bwp", "Pula botsuane" },
            { "byn", "Rubla bjelloruse" },
            { "byr", "Rubla bjelloruse (2000\u20132016)" },
            { "bzd", "Dollari i Ishujve Belize" },
            { "cad", "Dollari kanadez" },
            { "cdf", "Franga kongole" },
            { "chf", "Franga zvicerane" },
            { "clp", "Pesoja kiliane" },
            { "cnh", "Juani kinez (p\u00ebr treg t\u00eb jasht\u00ebm)" },
            { "cny", "Juani kinez" },
            { "cop", "Pesoja kolumbiane" },
            { "crc", "Koloni kostarikan" },
            { "cuc", "Pesoja kubaneze e shk\u00ebmbyeshme" },
            { "cup", "Pesoja kubaneze" },
            { "cve", "Eskudoja e Kepit t\u00eb Gjelb\u00ebr" },
            { "czk", "Koruna e \u00c7ekis\u00eb" },
            { "djf", "Franga xhibutiane" },
            { "dkk", "Korona daneze" },
            { "dop", "Pesoja dominikane" },
            { "dzd", "Dinari algjerian" },
            { "egp", "Sterlina egjiptiane" },
            { "ern", "Nakfa e Eritres\u00eb" },
            { "etb", "Bira etiopiane" },
            { "eur", "Euroja" },
            { "fjd", "Dollari i Fixhit" },
            { "fkp", "St\u00ebrlina e Ishujve Falkland" },
            { "gbp", "Sterlina britanike" },
            { "gel", "Laria gjeorgjiane" },
            { "ghs", "Sejda ganeze" },
            { "gip", "Sterlina e Gjibraltarit" },
            { "gmd", "Dalasi gambian" },
            { "gnf", "Franga guinease" },
            { "gtq", "Kuecali i Guatemal\u00ebs" },
            { "gyd", "Dollari guajanez" },
            { "hkd", "Dollari i Hong-Kongut" },
            { "hnl", "Lempira hondurase" },
            { "hrk", "Kuna kroate" },
            { "htg", "Gurdi haitian" },
            { "huf", "Forinta hungareze" },
            { "idr", "Rupia indoneziane" },
            { "ils", "Shekeli izrealit" },
            { "inr", "Rupia indiane" },
            { "iqd", "Dinari irakian" },
            { "irr", "Riali iranian" },
            { "isk", "Korona islandeze" },
            { "jmd", "Dollari xhamajkan" },
            { "jod", "Dinari jordanez" },
            { "jpy", "Jeni japonez" },
            { "kes", "Shilinga keniane" },
            { "kgs", "Soma kirgize" },
            { "khr", "Riali kamboxhian" },
            { "kmf", "Franga komore" },
            { "kpw", "Uoni koreano-verior" },
            { "krw", "Uoni koreano-jugor" },
            { "kwd", "Dinari kuvajtian" },
            { "kyd", "Dollari i Ishujve Kajman" },
            { "kzt", "Tenga kazake" },
            { "lak", "Kipa e Laosit" },
            { "lbp", "Sterlina libaneze" },
            { "lkr", "Rupia e Sri-Lank\u00ebs" },
            { "lrd", "Dollari liberian" },
            { "lsl", "Lota lesotiane" },
            { "ltl", "Lita lituaneze" },
            { "lvl", "Lata letoneze" },
            { "lyd", "Dinari libian" },
            { "mad", "Dirhami maroken" },
            { "mdl", "Leuja moldave" },
            { "mga", "Arieri malagez" },
            { "mkd", "Denari maqedonas" },
            { "mmk", "Kiata e Mianmarit" },
            { "mnt", "Tugrika mongole" },
            { "mop", "Pataka e Makaos" },
            { "mro", "Ugija mauritane (1973\u20132017)" },
            { "mru", "Ugija mauritane" },
            { "mur", "Rupia mauritiane" },
            { "mvr", "Rufiu i Maldivit" },
            { "mwk", "Kua\u00e7a malaviane" },
            { "mxn", "Pesoja meksikane" },
            { "myr", "Ringiti malajzian" },
            { "mzn", "Metikali i Mozambikut" },
            { "nad", "Dollari i Namibis\u00eb" },
            { "ngn", "Naira nigeriane" },
            { "nio", "Kordoba nikaraguane" },
            { "nok", "Korona norvegjeze" },
            { "npr", "Rupia nepaleze" },
            { "nzd", "Dollari i Zeland\u00ebs s\u00eb Re" },
            { "omr", "Riali i Omanit" },
            { "pab", "Balboa panameze" },
            { "pen", "Sola peruane" },
            { "pgk", "Kina e Guines\u00eb s\u00eb Re-Papua" },
            { "php", "Pesoja filipinase" },
            { "pkr", "Rupia pakistaneze" },
            { "pln", "Zllota polake" },
            { "pyg", "Guarani paraguaian" },
            { "qar", "Riali i Katarit" },
            { "ron", "Leuja rumune" },
            { "rsd", "Dinari serb" },
            { "rub", "Rubla ruse" },
            { "rwf", "Franga ruandeze" },
            { "sar", "Riali saudit" },
            { "sbd", "Dollari i Ishujve Solomon\u00eb" },
            { "scr", "Rupia e Ishujve Sishel\u00eb" },
            { "sdg", "Sterlina sudaneze" },
            { "sek", "Korona suedeze" },
            { "sgd", "Dollari i Singaporit" },
            { "shp", "Sterlina e Ishullit t\u00eb Sh\u00ebn-Helen\u00ebs" },
            { "sle", "Leoni i Sierra-Leones" },
            { "sll", "Leoni i Sierra-Leones (1964\u20142022)" },
            { "sos", "Shilinga somaleze" },
            { "srd", "Dollari surinamez" },
            { "ssp", "Sterlina sudanezo-jugore" },
            { "std", "Dobra e Sao-Tomes dhe Prinsipes (1977\u20132017)" },
            { "stn", "Dobra e Sao-Tomes dhe Prinsipes" },
            { "syp", "Sterlina siriane" },
            { "szl", "Lilangeni i Suaziland\u00ebs" },
            { "thb", "Bata tajlandeze" },
            { "tjs", "Somona taxhike" },
            { "tmt", "Manata turkmene" },
            { "tnd", "Dinari tunizian" },
            { "top", "Panga tongane" },
            { "try", "Lira turke" },
            { "ttd", "Dollari i Trinidadit dhe Tobagos" },
            { "twd", "Dollari tajvanez" },
            { "tzs", "Shilinga e Tanzanis\u00eb" },
            { "uah", "Rivnia ukrainase" },
            { "ugx", "Shilinga ugandeze" },
            { "usd", "Dollari amerikan" },
            { "uyu", "Pesoja uruguaiane" },
            { "uzs", "Soma uzbeke" },
            { "vef", "Bolivari venezuelian (2008\u20132018)" },
            { "ves", "Bolivari venezuelas" },
            { "vnd", "Donga vietnameze" },
            { "vuv", "Vatuja e Vanuatus\u00eb" },
            { "wst", "Tala samoane" },
            { "xaf", "Franga kamerunase" },
            { "xcd", "Dollari i Karaibeve Lindore" },
            { "xof", "Franga e Bregut t\u00eb Fildisht\u00eb" },
            { "xpf", "Franga franceze e Polinezis\u00eb" },
            { "xxx", "Valut\u00eb e panjohur" },
            { "yer", "Riali i Jemenit" },
            { "zar", "Randi afrikano-jugor" },
            { "zmw", "Kua\u00e7a e Zambikut" },
        };
        return data;
    }
}
